alloy-rlp-derive
This crate provides derive macros for traits defined in
alloy-rlp. See that crate’s documentation for
more information.
This library also supports up to 1 #[rlp(default)] in a struct, which is
similar to #[serde(default)]
with the caveat that we use the Default value if the field deserialization
fails, as we don’t serialize field names and there is no way to tell if it is
present or not.
Derive Macros
- RlpDecodable
- Derives
Decodablefor the type whose implementation expects an rlp-list input:<rlp-header, fields...> - RlpDecodable
Wrapper - Derives
Decodablefor the type whose implementation expects only the individual fields encoded:<fields...> - RlpEncodable
- Derives
Encodablefor the type which encodes the all fields as list:<rlp-header, fields...> - RlpEncodable
Wrapper - Derives
Encodablefor thenewtypewhich encodes its single field as-is, without a header:<field> - RlpMax
Encoded Len - Derives
MaxEncodedLenfor types of constant size.